@@ -87,7 +87,7 @@ class Builder(Update):
 
     """
 
-    class Method(object):
+    class Method():
         Prepare = "builder_prepare"
         Break = "builder_break"
         Update = "builder_update"
@@ -604,11 +604,11 @@ class Builder(Update):
 
     def regenCache(self, repname):
         with self.clVars.useDefaultModule("update"):
-            return super(Builder, self).regenCache(repname)
+            return super().regenCache(repname)
 
     def prepare_gpg(self):
         with self.clVars.useDefaultModule("update"):
-            return super(Builder, self).prepare_gpg()
+            return super().prepare_gpg()
 
     def getGit(self):
         chroot_path = self.clVars.Get('builder.cl_builder_path')
@@ -622,7 +622,7 @@ class Builder(Update):
     def syncRepositories(self, repname, fallback_sync=False,
                          clean_on_error=True):
         with self.clVars.useDefaultModule("update"):
-            return super(Builder, self).syncRepositories(
+            return super().syncRepositories(
                 repname, fallback_sync=fallback_sync,
                 clean_on_error=clean_on_error)
 
@@ -670,7 +670,7 @@ class Builder(Update):
             self.ListAction.Ask if not pretend else self.ListAction.OnlyShow,
             *params)
 
-    class ListAction(object):
+    class ListAction():
         Ask = "ask"
         OnlyShow = "only_show"
         ShowAndRun = "show_and_run"
@@ -829,7 +829,7 @@ class Builder(Update):
                                     "-1", *rebuild_list)
         return True
 
-    class Driver(object):
+    class Driver():
         Package = None
         Id = None
 
@@ -1338,13 +1338,12 @@ class Builder(Update):
                         path.basename(x) for x in removeList)
                     logger.info(removelist_str)
 
-                map(lambda x: os.unlink(x), 
-                    (pathJoin(pkgDir, x) for x in removeList))
+                [os.unlink(y) for y in (pathJoin(pkgDir, x) for x in removeList)]
 
-                # remove empty directories
-                map(lambda x: os.rmdir(x), (x for x in (path.join(pkgDir, y) for y 
-                    in os.listdir(pkgDir)) 
-                    if path.isdir(x) and not os.listdir(x)))
+                [os.rmdir(y) for y 
+                    in (path.join(pkgDir, x) for x 
+                        in os.listdir(pkgDir)) 
+                    if path.isdir(y) and not os.listdir(y)]
 
                 self.regenPackages(chrootPath, pkgDir[len(chrootPath):])
         except OSError as e:
@@ -1456,11 +1455,11 @@ class Builder(Update):
         digestfile = self._digest_file(isofile)
         try:
             with writeFile(digestfile) as f:
-                f.writelines(map(lambda x: template % {
+                f.writelines((template % {
                     'alg': x.upper(),
                     'digest':
                         process("%ssum" % x, isofile).read().partition(' ')[0],
-                    'filename': path.basename(isofile)}, ["md5", "sha1"]))
+                    'filename': path.basename(isofile)} for x in ["md5", "sha1"]))
         except (IOError, OSError):
             return False
         return True
@@ -1493,7 +1492,7 @@ class Builder(Update):
                 bdeps = " --with-bdeps=n"
             return deo + bdeps
         else:
-            return super(Builder, self).get_default_emerge_opts()
+            return super().get_default_emerge_opts()
 
     def emerge(self, builder_path, use, *params):
         extra_params = [x for x in params if x.startswith("-")]
@@ -1543,7 +1542,6 @@ class Builder(Update):
         :param exclude_files:
         :return:
         """
-        builder_path = builder_path.encode('utf-8')
         all_count = countFiles(builder_path)
         exclude_sum = sum(countFiles(path.join(builder_path, x))
                           for x in exclude_files)
@@ -1556,9 +1554,9 @@ class Builder(Update):
         devPath = path.join(directory, "dev")
         # clean dev
         for pathname, dirs, files in os.walk(devPath, topdown=False):
-            map(lambda x: os.unlink(path.join(pathname, x)), files)
-            map(lambda x: os.unlink(x) if path.islink(x) else os.rmdir(x),
-                (path.join(pathname, x) for x in dirs))
+            [os.unlink(path.join(pathname, x)) for x in files]
+            [os.unlink(x) if path.islink(x) else os.rmdir(x) for 
+                x in (path.join(pathname, x) for x in dirs)]
         for node, mode, dmode, major, minor in [
             ("console", 0o600, stat.S_IFCHR, 5, 1),
             ("tty1", 0o600, stat.S_IFCHR, 4, 1),
@@ -2202,7 +2200,7 @@ class Builder(Update):
     def update_binhost_list(self):
         self.invalidateVariables('cl_builder_linux_datavars')
         self.prepare_update_vars()
-        return super(Builder,self).update_binhost_list(
+        return super().update_binhost_list(
                      self.clVars.Get('cl_builder_linux_datavars'))
 
     def is_update_action(self, action):
